summaryrefslogtreecommitdiff
path: root/nuttx/include
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-08-19 14:17:25 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-08-19 14:17:25 +0000
commitd4047d8d6ae8fc7dd32cb47fd14e6a71386abf15 (patch)
treeb81722c6a29a4b9fa02578f36f027412cf4b7a89 /nuttx/include
parentee0edf356a193bfcfbee15cc649a3f90e5d26e06 (diff)
downloadpx4-nuttx-d4047d8d6ae8fc7dd32cb47fd14e6a71386abf15.tar.gz
px4-nuttx-d4047d8d6ae8fc7dd32cb47fd14e6a71386abf15.tar.bz2
px4-nuttx-d4047d8d6ae8fc7dd32cb47fd14e6a71386abf15.zip
Missing a some re-naming in the last checkin
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@3896 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include')
-rwxr-xr-xnuttx/include/nuttx/analog/adc.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/nuttx/include/nuttx/analog/adc.h b/nuttx/include/nuttx/analog/adc.h
index c820e762d..1afb5926d 100755
--- a/nuttx/include/nuttx/analog/adc.h
+++ b/nuttx/include/nuttx/analog/adc.h
@@ -72,6 +72,7 @@
/************************************************************************************
* Public Types
************************************************************************************/
+
struct adc_msg_s
{
uint8_t am_channel; /* The 8-bit ADC Channel */
@@ -131,20 +132,20 @@ struct adc_ops_s
* can_register() must allocate and initialize this structure. The
* calling logic need only set all fields to zero except:
*
* The elements of 'cd_ops', and 'cd_priv'
*
* The common logic will initialize all semaphores.
*/
struct adc_dev_s
{
- uint8_t cd_ocount; /* The number of times the device has been opened */
- uint8_t cd_nrxwaiters; /* Number of threads waiting to enqueue a message */
- sem_t cd_closesem; /* Locks out new opens while close is in progress */
- sem_t cd_recvsem; /* Used to wakeup user waiting for space in cd_recv.buffer */
- struct adc_fifo_s cd_recv; /* Describes receive FIFO */
- const struct adc_ops_s *cd_ops; /* Arch-specific operations */
- void *cd_priv; /* Used by the arch-specific logic */
+ uint8_t ad_ocount; /* The number of times the device has been opened */
+ uint8_t ad_nrxwaiters; /* Number of threads waiting to enqueue a message */
+ sem_t ad_closesem; /* Locks out new opens while close is in progress */
+ sem_t ad_recvsem; /* Used to wakeup user waiting for space in ad_recv.buffer */
+ struct adc_fifo_s ad_recv; /* Describes receive FIFO */
+ const struct adc_ops_s *ad_ops; /* Arch-specific operations */
+ void *ad_priv; /* Used by the arch-specific logic */
};
/************************************************************************************
@@ -131,20 +132,20 @@ struct adc_ops_s
* calling logic need only set all fields to zero except:
*
- * The elements of 'cd_ops', and 'cd_priv'
+ * The elements of 'ad_ops', and 'ad_priv'
*
* The common logic will initialize all semaphores.